@@ -3,7 +3,12 @@
 
 from optparse import OptionParser
 from simple_manager import __version__ as Version
-from simple_manager.utils import git_clone, git_push
+from simple_manager.utils import git_clone
+from simple_manager.utils import git_push
+from simple_manager.utils import git_push_tag
+from simple_manager.utils import git_update
+from simple_manager.utils import git_status
+from simple_manager.utils import get_last_tag
 
 import sys
 import subprocess
@@ -14,47 +19,25 @@ config = None
 WORKSPACE = None
 project = None
 
-def get_last_tag():
-    cmd = 'git describe --tags `git rev-list --tags --max-count=1`'
-    cwd = '%s/%s'% (WORKSPACE, config['projects'][project]['name'])
-
-    try:
-        tag = subprocess.Popen(cmd, stdout=subprocess.PIPE, shell=True, cwd=cwd).stdout.read()
-        print "Last tag for %s: %s" % (project, tag.replace("\n",""))
-        return tag
-    except:
-        print "No tags found for %s" % project
-
 def develop_install():
     cmd = ['python', 'setup.py', 'install', config['projects'][project]['repo']]
     p = subprocess.Popen(cmd, cwd=WORKSPACE)
     p.wait()
 
-def git_update():
-    print "Updating %s" % project
-    cmd = ['git', 'pull']
-    p = subprocess.Popen(cmd, cwd=WORKSPACE+'/'+config['projects'][project]['name'])
-    p.wait()
-
-def git_push_tag():
-    cmd = 'git push --tags'
-    cwd = '%s/%s'% (WORKSPACE, config['projects'][project]['name'])
-    subprocess.Popen(cmd, stdout=subprocess.PIPE, shell=True, cwd=cwd).stdout.read()
-
-def git_tag():
-    git_update()
-    tag = get_last_tag()
-
-    new_tag = raw_input("Enter new tag: ")
-    description = raw_input("Enter a description for this tag: ")
-
-    cmd = 'git tag -a %s -m "%s"' % (new_tag, description)
-    cwd = '%s/%s'% (WORKSPACE, config['projects'][project]['name'])
-
-    subprocess.Popen(cmd, stdout=subprocess.PIPE, shell=True, cwd=cwd).stdout.read()
-    
-    git_push(WORKSPACE, config['projects'][project]['name'])
-    git_push_tag()
+# def git_tag():
+#     git_update(WORKSPACE, config['projects'][project]['name'])
+#     tag = get_last_tag()
+# 
+#     new_tag = raw_input("Enter new tag: ")
+#     description = raw_input("Enter a description for this tag: ")
+# 
+#     cmd = 'git tag -a %s -m "%s"' % (new_tag, description)
+#     cwd = '%s/%s'% (WORKSPACE, config['projects'][project]['name'])
+# 
+#     subprocess.Popen(cmd, stdout=subprocess.PIPE, shell=True, cwd=cwd).stdout.read()
+#     
+#     git_push(WORKSPACE, config['projects'][project]['name'])
+#     git_push_tag(WORKSPACE, config['projects'][project]['name'])
 
 def main(argv):
     global config
@@ -74,6 +57,8 @@ def main(argv):
 
     parser.add_option("-u", "--update", action="store_true", dest="update", help="Update repositories.")
 
+    parser.add_option("-s", "--status", action="store_true", dest="status", help="See repositories statuses.")
+
     parser.add_option("-T", "--TAGS", action="store_true", dest="tags",
                       help="Show last tags por all configured repositories")
 
@@ -106,14 +91,21 @@ def main(argv):
 
     if options.update:
         if project != 'all':
-            git_update()
+            git_update(WORKSPACE, project)
         else:
-            print "Updating %s"  % ', '.join(config['projects'].keys())
             for repo in config['projects'].keys():
                 project = repo
-                git_update()
+                git_update(WORKSPACE, project)
 
-    elif options.clone:
+    if options.status:
+        if project != 'all':
+            git_status(WORKSPACE, project)
+        else:
+            for repo in config['projects'].keys():
+                project = repo
+                git_status(WORKSPACE, project)
+
+    if options.clone:
         if project != 'all':
             git_clone(project=project,
                       url=config['projects'][project]['repo'],
@@ -136,12 +128,12 @@ def main(argv):
 
     elif options.tags:
         if project != 'all':
-            get_last_tag()
+            get_last_tag(WORKSPACE, project)
         else:
             print "Getting last tags for %s"  % ', '.join(config['projects'].keys())
             for repo in config['projects'].keys():
                 project = repo
-                get_last_tag()
+                get_last_tag(WORKSPACE, project)
 
     elif options.tag:
         if project != 'all':
